[![image](https://img.shields.io/pypi/v/genascii.svg)](https://pypi.python.org/pypi/genascii)
[![image](https://img.shields.io/pypi/l/genascii.svg)](https://github.com/astral-sh/genascii/blob/main/LICENSE)
[![image](https://img.shields.io/pypi/pyversions/genascii.svg)](https://pypi.python.org/pypi/genascii)
[![image](https://static.pepy.tech/badge/genascii)](https://pepy.tech/project/genascii)

## Install

```sh
pip install genascii
```

## Usage

Image to ASCII text:

```sh
python -m genascii img2txt --input /path/to/image.jpg --output /path/to/output.txt
```

Image to ASCII image:

```sh
python -m genascii img2img --input /path/to/image.jpg --output /path/to/output.jpg
```

Video to ASCII video:

```sh
python -m genascii video2video --input /path/to/image.mp4 --output /path/to/output.mp4
```
